@@ -1,17 +1,18 @@
 ## File Name: IRT.posterior_sirt.R
-## File Version: 0.12
+## File Version: 0.15
 
 
 
 ########################################################
 # posterior rasch.copula2
-IRT.posterior.rasch.copula2 <- function( object, ... ){
+IRT.posterior.rasch.copula2 <- function( object, ... )
+{
     ll <- object$f.qk.yi
     attr(ll,"theta") <- vec2mat.sirt( object$theta.k )
     attr(ll,"prob.theta") <- object$pi.k
     attr(ll,"G") <- 1
     return(ll)
-        }
+}
 IRT.posterior.rasch.copula3 <- IRT.posterior.rasch.copula2
 ##########################################################
 
@@ -19,13 +20,14 @@ IRT.posterior.rasch.copula3 <- IRT.posterior.rasch.copula2
 
 ##########################################################
 # posterior rasch.mml2
-IRT.posterior.rasch.mml <- function( object, ... ){
+IRT.posterior.rasch.mml <- function( object, ... )
+{
     ll <- object$f.qk.yi
     attr(ll,"theta") <- vec2mat.sirt( object$theta.k )
     attr(ll,"prob.theta") <- object$pi.k
     attr(ll,"G") <- object$G
     return(ll)
-        }
+}
 ##########################################################
 # smirt
 IRT.posterior.smirt <- IRT.posterior.rasch.mml
@@ -45,22 +47,24 @@ IRT.posterior.prob.guttman <- IRT.posterior.rasch.mml
 
 ##########################################################
 # posterior rasch.mirtlc
-IRT.posterior.rasch.mirtlc <- function( object, ... ){
+IRT.posterior.rasch.mirtlc <- function( object, ... )
+{
     ll <- object$estep.res$f.qk.yi
     attr(ll,"theta") <- vec2mat.sirt( object$theta.k )
     attr(ll,"prob.theta") <- object$pi.k
     attr(ll,"G") <- object$G
     return(ll)
-        }
+}
 ##########################################################
 
 ##########################################################
 # posterior xxirt
-IRT.posterior.xxirt <- function( object, ... ){
+IRT.posterior.xxirt <- function( object, ... )
+{
     ll <- object$p.aj.xi
     attr(ll,"theta") <- object$Theta
     attr(ll,"prob.theta") <- object$probs_Theta
     attr(ll,"G") <- object$G
     return(ll)
-        }
+}
 ##########################################################
