@@ -1,5 +1,5 @@
 ## File Name: data.recode.sirt.R
-## File Version: 0.01
+## File Version: 0.02
 
 
 #*** utility function for recoding a raw dataset
@@ -9,7 +9,7 @@ data.recode.sirt <- function( data.raw, keys )
     V <- ncol(data.raw)
     data.scored <- matrix( 0, nrow(data.raw), ncol(data.raw) )
     colnames(data.scored) <- colnames(data.raw )
-    for (vv in 1:V){
+    for (vv in 1L:V){
         data.scored[,vv] <- 1* ( paste(data.raw[,vv])==
                     paste(item.stat[ item.stat$item==colnames(data.raw)[vv], 'key' ]) )
         data.scored[ paste( data.raw[,vv] )=='NA', vv ] <- NA
