@@ -1,12 +1,12 @@
 ## File Name: fit.logistic.R
-## File Version: 2.13
+## File Version: 2.15
 
 
-###################################################
-# fit logistic model
+
+#-- fit logistic model
 fit.logistic <- function( freq.correct, wgt, scores, item.p,
-    conv=.0001, maxit=100, progress=TRUE ){
-    #*************************
+    conv=.0001, maxit=100, progress=TRUE )
+{
     sc.adj <- min( diff(scores) ) / 3
     scores1 <- scores
     freq.correct <- as.matrix(freq.correct)
@@ -14,30 +14,26 @@ fit.logistic <- function( freq.correct, wgt, scores, item.p,
     CC <- ncol(freq.correct)
     scores1[ scores==0 ] <- sc.adj
     scores1[ scores==1 ] <- 1 - sc.adj
-    dfr0 <- data.frame( "stud.index"=rep(1:RR, CC),
-                "item.index"=rep(1:CC,each=RR),
-                "stud.p"=rep( scores1,CC),
-                "item.p"=rep( item.p, each=RR ),
-                "wgt"=matrix( as.matrix( wgt ), RR*CC, 1 ),
-                "p0"=matrix( as.matrix(freq.correct ), RR*CC, 1 )
-                        )
-#    dfr0$item.plogis <- qlogis( dfr0$item.p)
-#    dfr0$stud.plogis <- qlogis( dfr0$stud.p)
+    dfr0 <- data.frame( stud.index=rep(1:RR, CC),
+                item.index=rep(1:CC,each=RR),
+                stud.p=rep( scores1,CC),
+                item.p=rep( item.p, each=RR ),
+                wgt=matrix( as.matrix( wgt ), RR*CC, 1 ),
+                p0=matrix( as.matrix(freq.correct ), RR*CC, 1 ) )
     if (progress){
         cat("\n*******Logistic Model***********\n")
-#        cat("*** ", paste(Sys.time()), "*******\n")
-            }
+    }
     theta <- stats::qlogis( scores1 )
     b <- stats::qlogis( item.p )
-    #***********************************
-    # begin algorithm
+
+    #*** begin algorithm
     numdiff.parm <- .001
     max.increment <- 1
     deviation <- 1000
     iter <- 0
     # adjust freq.correct if necessary
     adj <- min( c( min( freq.correct[ freq.correct > 0 ] ),
-            1-max( freq.correct[ freq.correct < 1 ] )    ) ) / 3
+            1-max( freq.correct[ freq.correct < 1 ] ) ) ) / 3
     freq.correct1 <- freq.correct
     freq.correct1[ freq.correct==0 ] <- adj
     freq.correct1[ freq.correct==1 ] <- 1-adj
@@ -56,11 +52,11 @@ fit.logistic <- function( freq.correct, wgt, scores, item.p,
         b <- b - mean(b)
         deviation <- max( abs( c( theta-theta0, b - b0 )) )
         if (progress){
-                cat( "Iteration", iter, "- Deviation=",  round( deviation, 6 ), "\n")
-                flush.console()
-                    }
+            cat( "Iteration", iter, "- Deviation=",  round( deviation, 6 ), "\n")
+            utils::flush.console()
+        }
         iter <- iter + 1
-            }  # end algorithm
+    }  # end algorithm
     #*************************
     dfr0$irtfitted <- matrix( plogis( outer(theta, b, "+") ), RR*CC, 1 )[,1]
     Y <- 0*freq.correct
@@ -79,20 +75,16 @@ fit.logistic <- function( freq.correct, wgt, scores, item.p,
     wgt1 <- ( wgt / colSums( wgt ) ) / ncol(wgt)
     fit <- sqrt( sum( ( freq.correct - G  )^2 * wgt1  ) )
     # calculate likelihood
-    ll <- list(
-        "ll.ind"=.calc.ll.isop( freq.correct, wgt, irtfitted=freq.correct )
-                    )
+    ll <- list( ll.ind=.calc.ll.isop( freq.correct, wgt, irtfitted=freq.correct ) )
     ll$ll.logistic <- .calc.ll.isop( freq.correct, wgt, irtfitted=G )
     NW <- mean( colSums(wgt) )
     ll$llcase.ind <- ll$ll.ind/NW
     ll$llcase.logistic <- ll$ll.logistic/NW
-#    if (progress){
-#        cat("*** ", paste(Sys.time()), "*******\n")
-#            }
+
     # output
     res <- list( "fX"=G, "ResX"=freq.correct - G,
                 "fit"=fit, "item.sc"=b,
                 "person.sc"=theta, "ll"=ll, "freq.fitted"=dfr0)
     return(res)
-    }
-####################################################################
+}
+
