@@ -1,5 +1,5 @@
 ## File Name: gom_em_calc_theta.R
-## File Version: 0.17
+## File Version: 0.181
 
 
 #--- calculate theta grid
@@ -9,9 +9,9 @@ gom_em_calc_theta <- function( K, problevels, eps=1e-5 )
     if ( ! is.matrix(problevels) ){
         PL <- length(problevels)
         m1 <- matrix(problevels, PL, 1 )
-        for (kk in 2:K){
+        for (kk in 2L:K){
             NM <- nrow(m1)
-            m1 <- cbind( m1[ rep( 1:NM, PL), ], rep( problevels, each=NM)  )
+            m1 <- cbind( m1[ rep( 1L:NM, PL), ], rep( problevels, each=NM)  )
             m1 <- m1[ rowSums(m1) <=1, ]
         }
     }
