@@ -1,5 +1,5 @@
 ## File Name: linking_haberman_als_vcov.R
-## File Version: 0.165
+## File Version: 0.167
 
 linking_haberman_als_vcov <- function( regr_resid, regr_wgt, transf_pars,
         selitems, estimation="OLS", vcov=TRUE, NS=NULL )
@@ -14,15 +14,14 @@ linking_haberman_als_vcov <- function( regr_resid, regr_wgt, transf_pars,
     }
     N <- nrow(regr_resid)
     data <- data.frame( y=matrix( regr_resid, ncol=1 ),
-                        study=rep(1:NS, each=N) )
+                        study=rep(1L:NS, each=N) )
     data$wgt <- matrix( regr_wgt, ncol=1 )
     data <- stats::na.omit(data)
-    for (ss in 2:NS){
+    for (ss in 2L:NS){
         data[, paste0('X', ss) ] <- 1*(data$study==ss)
     }
-    # form <- paste0( 'y ~ 0 + ', paste0('X', 2:NS, collapse=' + ' ) )
     if (vcov){
-        form <- paste0( 'y ~ ', paste0('X', 2:NS, collapse=' + ' ) )
+        form <- paste0( 'y ~ ', paste0('X', 2L:NS, collapse=' + ' ) )
         mod <- stats::lm( stats::as.formula(form), data=data, weights=data$wgt )
         mod_vcov <- stats::vcov(mod)
         vcov <- mod_vcov[-1,-1]
