@@ -1,5 +1,5 @@
 ## File Name: linking_haberman_compute_lts_mean.R
-## File Version: 0.08
+## File Version: 0.091
 
 linking_haberman_compute_lts_mean <- function(x, w, lts_prop, maxiter=10)
 {
@@ -11,15 +11,15 @@ linking_haberman_compute_lts_mean <- function(x, w, lts_prop, maxiter=10)
     if (n < k){
         k <- n
     }
-    index <- 1:k
+    index <- 1L:k
     m1 <- stats::weighted.mean(x=x, w=w)
     iter <- 0
     iterate <- TRUE
-    dfr <- data.frame(index=1:n, x=x, e=x-m1, w=w)
+    dfr <- data.frame(index=1L:n, x=x, e=x-m1, w=w)
     while(iterate){
         m0 <- m1
         dfr <- dfr[ order(abs(dfr$e)), ]
-        m1 <- stats::weighted.mean(x=dfr$x[1:k], w=dfr$w[1:k])
+        m1 <- stats::weighted.mean(x=dfr$x[1L:k], w=dfr$w[1L:k])
         dfr$e <- dfr$x - m1
         iter <- iter + 1
         if (iter>maxiter){ iterate <- FALSE }
