@@ -1,5 +1,5 @@
 ## File Name: linking_haebara_gradient_function_R.R
-## File Version: 0.292
+## File Version: 0.294
 
 
 linking_haebara_gradient_function_R <- function(NI, NS, dist, aM, bM, theta,
@@ -11,23 +11,23 @@ linking_haebara_gradient_function_R <- function(NI, NS, dist, aM, bM, theta,
     # th=SIG*TH+MU=> logit(p)=a*(SIG*TH+MU-b)=a*SIG*(TH-(-MU)/SIG-b/SIG)
     grad <- rep(0, 2*NI+2*(NS-1) )
     names(grad) <- parnames
-    for (ii in 1:NI){
-        for (ss in 1:NS){
+    for (ii in 1L:NI){
+        for (ss in 1L:NS){
             if (est_pars[ii,ss]){
                 p_obs <- stats::plogis( aM[ii,ss] * (theta - bM[ii,ss] ) )
                 a_exp <- a[ii] * sigma[ss]
                 b_exp <- ( b[ii] - mu[ss] ) / sigma[ss]
                 p_exp <- stats::plogis( a_exp * (theta - b_exp ) )
                 der <- p_exp*(1-p_exp)
-                if (dist=="L2"){
+                if (dist=='L2'){
                     der_basis <- -2*(p_obs - p_exp)*prob_theta*der
                 }
-                if (dist=="L1"){
+                if (dist=='L1'){
                     diff2 <- p_obs - p_exp
                     dist2 <- diff2^2
                     der_basis <- -(dist2+eps)^(-.5)*diff2*prob_theta*der
                 }
-                if (dist=="Lp"){
+                if (dist=='Lp'){
                     diff2 <- p_obs - p_exp
                     dist2 <- diff2^2
                     der_basis <- -pow*(dist2+eps)^(pow/2-1)*diff2*prob_theta*der
