@@ -1,5 +1,5 @@
 ## File Name: linking_haebara_optim_function_R.R
-## File Version: 0.171
+## File Version: 0.174
 
 
 linking_haebara_optim_function_R <- function(NI, NS, dist, aM, bM, theta,
@@ -8,16 +8,13 @@ linking_haebara_optim_function_R <- function(NI, NS, dist, aM, bM, theta,
     # logit(p)=a*(th-b)
     # th=SIG*TH+MU=> logit(p)=a*(SIG*TH+MU-b)=a*SIG*(TH-(-MU)/SIG-b/SIG)
     val <- 0
-    for (ii in 1:NI){
-        for (ss in 1:NS){
+    for (ii in 1L:NI){
+        for (ss in 1L:NS){
             if (est_pars[ii,ss]){
                 p_obs <- stats::plogis( aM[ii,ss] * (theta - bM[ii,ss] ) )
                 a_exp <- a[ii] * sigma[ss]
                 b_exp <- ( b[ii] - mu[ss] ) / sigma[ss]
-                # p_exp <- stats::plogis( a_exp * (theta - b_exp ) )
                 p_exp <- stats::plogis( a_exp*theta - a[ii]*( b[ii] - mu[ss] ) )
-                ## a_exp[ii]=a[ii]*sigma[ss]
-                ## a_exp[ii] * b_exp[ii]=a[ii]*(b[ii]-mu[ss])
                 dist2 <- (p_obs - p_exp)^2
                 if (dist=='L2'){
                     dist1 <- sum( dist2*prob_theta )
