@@ -1,17 +1,17 @@
 ## File Name: lsem_fitsem_verbose_start.R
-## File Version: 0.04
+## File Version: 0.05
 
 lsem_fitsem_verbose_start <- function(G, verbose)
 {
     pr <- NULL
     if (verbose){
-        cat( "** Fit lavaan model\n")
+        cat( '** Fit lavaan model\n')
         G1 <- min(G,10)
         pr <- round( seq(1, G, len=G1) )
-        cat("|")
-        cat( paste0( rep("*",G1), collapse="") )
-        cat("|\n")
-        cat("|")
+        cat('|')
+        cat( paste0( rep('*',G1), collapse='') )
+        cat('|\n')
+        cat('|')
     }
     return(pr)
 }
