@@ -1,5 +1,5 @@
 ## File Name: mcmc_Rhat.R
-## File Version: 0.11
+## File Version: 0.121
 
 mcmc_Rhat <- function( mcmc_object, n_splits=3 )
 {
@@ -8,11 +8,10 @@ mcmc_Rhat <- function( mcmc_object, n_splits=3 )
     n_within <- floor( n_samples / n_splits )
     rhat_vec <- rep(NA, n_pars)
     names(rhat_vec) <- colnames(mcmc_object)
-    for (pp in 1:n_pars){
-        # pp <- 1
+    for (pp in 1L:n_pars){
         matr <- matrix( NA, nrow=n_within, ncol=n_splits)
-        for (ss in 1:n_splits){
-            matr[,ss] <- mcmc_object[ (ss-1)* n_within + 1:n_within, pp ]
+        for (ss in 1L:n_splits){
+            matr[,ss] <- mcmc_object[ (ss-1)* n_within + 1L:n_within, pp ]
         }
         rhat_vec[pp] <- Rhat1(matr)
     }
