@@ -1,10 +1,10 @@
 ## File Name: mcmc_as_formula.R
-## File Version: 0.11
+## File Version: 0.121
 
 mcmc_as_formula <- function( string )
 {
-    string <- paste0( string, collapse=" " )
-    string <- gsub("___ ", "___", string, fixed=TRUE )
+    string <- paste0( string, collapse=' ' )
+    string <- gsub('___ ', '___', string, fixed=TRUE )
     form <- stats::as.formula(string)
     return(form)
 }
