@@ -1,5 +1,5 @@
 ## File Name: mcmc_derivedPars.R
-## File Version: 0.323
+## File Version: 0.324
 
 
 #--- derived parameters for objects of class mcmc
@@ -14,7 +14,7 @@ mcmc_derivedPars <- function( mcmcobj, derivedPars )
     trans <- res$trans
     colnames(data) <- mcmc_rename_parameter_names( vec=colnames(data),
                                 orig=orig, trans=trans)
-    for (pp in 1:NP){
+    for (pp in 1L:NP){
         der_pp <- mcmc_rename_parameter_names( vec=paste0(derivedPars[[pp]]),
                                 orig=orig, trans=trans)
         form_pp <- mcmc_as_formula(der_pp)
@@ -27,7 +27,7 @@ mcmc_derivedPars <- function( mcmcobj, derivedPars )
     }
     colnames(data) <- mcmc_rename_undo_parameter_names( vec=colnames(data),
                                 orig=orig, trans=trans)
-    a1 <- attr( mcmcobj, "mcpar")
+    a1 <- attr( mcmcobj, 'mcpar')
     res <- sirt_import_coda_mcmc( data=data,  start=a1[1], end=a1[2], thin=a1[3] )
     return(res)
 }
