@@ -1,12 +1,12 @@
 ## File Name: mgsem_create_index.R
-## File Version: 0.03
+## File Version: 0.04
 
 
 mgsem_create_index <- function(x, all=TRUE, start=0, symm=FALSE, onlydiag=FALSE)
 {
     ND <- prod(dim(x))
     if (start>0){
-        v <- matrix( start + ( 1:ND ) - 1, nrow=dim(x)[1], ncol=dim(x)[2])
+        v <- matrix( start + ( 1L:ND ) - 1, nrow=dim(x)[1], ncol=dim(x)[2])
         if (symm){
             v <- v + t(v)
             v <- as.vector(v)
@@ -23,7 +23,7 @@ mgsem_create_index <- function(x, all=TRUE, start=0, symm=FALSE, onlydiag=FALSE)
     if (onlydiag){
         ND <- dim(x)[1]
         if (start>0){
-            v <- diag( start - 1 + 1:ND )
+            v <- diag( start - 1 + 1L:ND )
         } else {
             v <- diag( rep(1, dim(x)[1]))
         }
