@@ -1,5 +1,5 @@
 ## File Name: noharm_sirt_preproc.R
-## File Version: 0.398
+## File Version: 0.409
 
 
 #**** data preprocessing noharm.sirt
@@ -58,23 +58,23 @@ noharm_sirt_preproc <- function( dat, pm, N, weights, Fpatt, Fval,
 
     # CFA or EFA?
     if ( is.null(dimensions) ){
-        model.type <- "CFA"
+        model.type <- 'CFA'
         modtype <- 3    # 3 - multidimensional CFA
     } else {
-        model.type <- "EFA"
+        model.type <- 'EFA'
         modtype <- 2    # 2 - multidimensional EFA
         D <- dimensions
         Pval <- diag(D)
         Ppatt <- 0*diag(D)
         Fpatt <- matrix(1,nrow=I,ncol=D)
         if (D>1){
-            for (dd in 2:D){
-                Fpatt[dd,1:(dd-1)] <- 0
+            for (dd in 2L:D){
+                Fpatt[dd,1L:(dd-1)] <- 0
             }
         }
         Fval <- .5*(Fpatt>0)
         if ( D==1 ){ # 1 dimension
-            model.type <- "CFA"
+            model.type <- 'CFA'
             modtype <- 3
         }
     }
@@ -93,13 +93,14 @@ noharm_sirt_preproc <- function( dat, pm, N, weights, Fpatt, Fval,
         wgtm.default <- TRUE
     }
     diag(wgtm) <- 0
+    wgtm <- ( wgtm + t(wgtm) ) / 2
     wgtm <- wgtm * ( ss > 0 )
     res$wgtm <- wgtm
     res$sumwgtm <- ( sum( wgtm > 0 ) - sum( diag(wgtm) > 0 ) ) / 2
 
     #*** column names
     D <- ncol(Ppatt)
-    cn <- paste0("F",1:D)
+    cn <- paste0('F',1L:D)
     if (is.null(colnames(Fpatt) ) ){
         colnames(Fpatt) <- cn
     }
@@ -119,14 +120,15 @@ noharm_sirt_preproc <- function( dat, pm, N, weights, Fpatt, Fval,
 
     # F
     parm_table <- noharm_sirt_preproc_parameter_table_matrix(pattmat=Fpatt, valmat=Fval,
-            patt_id=1, patt_label="F", minval=0, symm=FALSE)
+            patt_id=1, patt_label='F', minval=0, symm=FALSE)
     # P
     parm1 <- noharm_sirt_preproc_parameter_table_matrix(pattmat=Ppatt, valmat=Pval,
-            patt_id=2, patt_label="P", minval=max(parm_table$index, na.rm=TRUE), symm=TRUE)
+            patt_id=2, patt_label='P', minval=sirt_max(parm_table$index), symm=TRUE)
     parm_table <- rbind(parm_table, parm1)
+
     # Psi
     parm1 <- noharm_sirt_preproc_parameter_table_matrix(pattmat=Psipatt, valmat=Psival,
-            patt_id=3, patt_label="Psi", minval=max(parm_table$index, na.rm=TRUE), symm=TRUE)
+            patt_id=3, patt_label='Psi', minval=sirt_max(parm_table$index), symm=TRUE)
     parm_table <- rbind(parm_table, parm1)
     parm_table <- parm_table[ parm_table$nonnull_par==1, ]
     rownames(parm_table) <- NULL
@@ -135,7 +137,7 @@ noharm_sirt_preproc <- function( dat, pm, N, weights, Fpatt, Fval,
     # indices
     ip <- parm_table$index
     ip[duplicated(ip)] <- NA
-    extract_index <- match(1:npar, ip)
+    extract_index <- match(1L:npar, ip)
     extract_index <- intersect( which( ! is.na( parm_table$index ) ),
                             which( ! duplicated( parm_table$index ) ) )
     parm_table$est <- parm_table$starts
@@ -144,44 +146,43 @@ noharm_sirt_preproc <- function( dat, pm, N, weights, Fpatt, Fval,
 
     ind <- NULL
     if (pos.variance){
-        ind1 <- which((parm_table$mat=="P") & (parm_table$row==parm_table$col ))
+        ind1 <- which((parm_table$mat=='P') & (parm_table$row==parm_table$col ))
         ind <- union(ind, ind1)
     }
     if (pos.loading){
-        ind1 <- which((parm_table$mat=="F") )
+        ind1 <- which((parm_table$mat=='F') )
         ind <- union(ind, ind1)
     }
     if (pos.residcorr){
-        ind1 <- which((parm_table$mat=="Psi") )
+        ind1 <- which((parm_table$mat=='Psi') )
         ind <- union(ind, ind1)
     }
-    parm_table[ind, "lower"] <- 0
-    parm_table[ is.na(parm_table$index), "lower"] <- NA
-
+    parm_table[ind, 'lower'] <- 0
+    parm_table[ is.na(parm_table$index), 'lower'] <- NA
     non_fixed <- ! parm_table$fixed
     include_index <- parm_table$index[ non_fixed ]
     parm_table$nonnull_par <- NULL
-    attr(parm_table, "extract_index") <- extract_index
-    attr(parm_table, "non_fixed") <- non_fixed
-    attr(parm_table, "include_index") <- include_index
-    attr(parm_table, "npar") <- npar
-    attr(parm_table, "NH") <- sum(non_fixed)
-    attr(parm_table, "est_par_index") <- which(parm_table$est_par==1)
-    attr(parm_table, "parm_table_free_index") <- which(parm_table$fixed==0)
+    attr(parm_table, 'extract_index') <- extract_index
+    attr(parm_table, 'non_fixed') <- non_fixed
+    attr(parm_table, 'include_index') <- include_index
+    attr(parm_table, 'npar') <- npar
+    attr(parm_table, 'NH') <- sum(non_fixed)
+    attr(parm_table, 'est_par_index') <- which(parm_table$est_par==1)
+    attr(parm_table, 'parm_table_free_index') <- which(parm_table$fixed==0)
 
     parm_index <- list()
-    for (mat_label in c("F", "P", "Psi") ){
+    for (mat_label in c('F', 'P', 'Psi') ){
         ind_mat <- which(parm_table$mat==mat_label)
         parm_index[[ mat_label ]] <- list()
-        parm_index[[ mat_label ]][[ "row_parm_table" ]] <- ind_mat
-        parm_index[[ mat_label ]][[ "entries" ]] <- parm_table[ ind_mat, c("row","col")]
-        parm_index[[ mat_label ]][[ "len" ]] <- length(ind_mat)
+        parm_index[[ mat_label ]][[ 'row_parm_table' ]] <- ind_mat
+        parm_index[[ mat_label ]][[ 'entries' ]] <- parm_table[ ind_mat, c('row','col')]
+        parm_index[[ mat_label ]][[ 'len' ]] <- length(ind_mat)
         nrow <- I
         ncol <- D
-        if (mat_label=="P"){ nrow <- D}
-        if (mat_label=="Psi"){ ncol <- I}
-        parm_index[[ mat_label ]][["nrow"]] <- nrow
-        parm_index[[ mat_label ]][["ncol"]] <- ncol
+        if (mat_label=='P'){ nrow <- D}
+        if (mat_label=='Psi'){ ncol <- I}
+        parm_index[[ mat_label ]][['nrow']] <- nrow
+        parm_index[[ mat_label ]][['ncol']] <- ncol
     }
 
     res$parm_table <- parm_table
