@@ -1,5 +1,5 @@
 ## File Name: resp_groupwise.R
-## File Version: 0.11
+## File Version: 0.121
 
 resp_groupwise <- function(resp, group, items_group)
 {
@@ -18,7 +18,7 @@ resp_groupwise <- function(resp, group, items_group)
             v1 <- rep(NA, N)
             v1[ ind_gg ] <- resp[ ind_gg, item_ii]
             dat[ ind_gg, item_ii ] <- NA
-            name_gg <- paste0(item_ii, "_Gr", group_ii[gg])
+            name_gg <- paste0(item_ii, '_Gr', group_ii[gg])
             dat <- data.frame(dat, v1)
             colnames(dat)[ ncol(dat) ] <- name_gg
         }
