@@ -1,5 +1,5 @@
 ## File Name: rm_proc_create_pseudoraters.R
-## File Version: 0.12
+## File Version: 0.133
 
 rm_proc_create_pseudoraters <- function( dat, rater, pid, reference_rater=NULL )
 {
@@ -15,17 +15,17 @@ rm_proc_create_pseudoraters <- function( dat, rater, pid, reference_rater=NULL )
     m0 <- as.data.frame( matrix(NA, nrow=nrow(dat0), ncol=I) )
     colnames(m0) <- colnames(dat0)
 
-    for (ii in 1:I){
+    for (ii in 1L:I){
         dat_ii <- m0
         dat_ii[, ii ] <- dat0[,ii]
-        rater_ii <- paste0( rater0, "-", items[ii] )
+        rater_ii <- paste0( rater0, '-', items[ii] )
         rater <- c( paste(rater), paste(rater_ii) )
         dat <- rbind( dat, dat_ii)
         pid <- c( pid, pid0)
     }
 
     if ( ! is.null(reference_rater) ){
-        reference_rater <- paste0(reference_rater, "-", items )
+        reference_rater <- paste0(reference_rater, '-', items )
     }
 
     #-- output
