@@ -1,11 +1,12 @@
 ## File Name: rm_sdt_create_partable_define_pargroups.R
-## File Version: 0.06
+## File Version: 0.09
 
 
 rm_sdt_create_partable_define_pargroups <- function(partable, pg1, pg2)
 {
     partable$pargroup <- 0
-    K <- max( partable$row, na.rm=TRUE)
+    # K <- max( partable$row, na.rm=TRUE)
+    K <- max( partable$col, na.rm=TRUE)  # changed ARb 2019-07-21
     for (kk in 1:K){
         m1 <- max(partable$pargroup) + 1
         ind <- ( partable$type==pg1 ) & ( partable$col==kk)
