@@ -1,5 +1,5 @@
 ## File Name: sia_sirt_remove_transitive.R
-## File Version: 0.13
+## File Version: 0.141
 
 
 #**** remove transitive relations
@@ -12,8 +12,8 @@ sia_sirt_remove_transitive <- function(I1){
     while (BB > .0001){
         I0 <- IS
         iter <- iter + 1
-        for (ii in 1:I ){
-            for (jj in 1:I){
+        for (ii in 1L:I ){
+            for (jj in 1L:I){
                 if (ii!=jj ){
                     if ( sum( IS[ii,] * IS[,jj] ) > 0 ){
                             I1[ii,jj] <- 0
