@@ -1,5 +1,5 @@
 ## File Name: sim.raschtype.R
-## File Version: 0.23
+## File Version: 0.242
 
 
 
@@ -11,7 +11,7 @@ sim.raschtype <- function( theta, b, alpha1=0, alpha2=0, fixed.a=NULL,
     if ( is.null(fixed.c)){ fixed.c <- 0*b }
     if ( is.null(fixed.d)){ fixed.d <- 1 + 0*b}
     # latent response (subtraction)
-    latresp <- TAM::tam_outer( theta, b, op="-" )
+    latresp <- TAM::tam_outer( theta, b, op='-' )
     # include slope simulation
     TP <- length(theta)
     latresp <- sirt_matrix2( fixed.a, nrow=TP ) * latresp
@@ -26,7 +26,7 @@ sim.raschtype <- function( theta, b, alpha1=0, alpha2=0, fixed.a=NULL,
     # define response matrix
     dat.resp <- 1 * ( expprob > matrix( stats::runif(N*I), ncol=I) )
     pot <- max( 2, floor(log10(I) + 1 ) )
-    colnames(dat.resp) <- paste( "I", substring( 10^pot + 1:I,2), sep="")
+    colnames(dat.resp) <- paste( 'I', substring( 10^pot + 1L:I,2), sep='')
     dat.resp <- as.data.frame(dat.resp)
     return(dat.resp)
 }
