@@ -1,9 +1,9 @@
 ## File Name: sirt_import_MASS_ginv.R
-## File Version: 0.12
+## File Version: 0.13
 
 sirt_import_MASS_ginv <- function(X,...)
 {
-    TAM::require_namespace_msg("MASS")
+    TAM::require_namespace_msg('MASS')
     y <- MASS::ginv(X=X, ...)
     return(y)
 }
