@@ -1,9 +1,9 @@
 ## File Name: sirt_import_coda_as.mcmc.list.R
-## File Version: 0.01
+## File Version: 0.02
 
 sirt_import_coda_as.mcmc.list <- function(...)
 {
-    TAM::require_namespace_msg("coda")
+    TAM::require_namespace_msg('coda')
     res <- coda::as.mcmc.list(...)
     return(res)
 }
