@@ -1,5 +1,5 @@
 ## File Name: sirt_rbind_fill.R
-## File Version: 0.05
+## File Version: 0.06
 
 ## reimplementation of plyr::rbind.fill
 
@@ -11,7 +11,7 @@ sirt_rbind_fill <- function( x, y )
     z <- matrix( NA, nrow=nx+ny, ncol=length(vars) )
     colnames(z) <- vars
     z <- as.data.frame(z)
-    z[ 1:nx, colnames(x) ] <- x
-    z[ nx + 1:ny, colnames(y) ] <- y
+    z[ 1L:nx, colnames(x) ] <- x
+    z[ nx + 1L:ny, colnames(y) ] <- y
     return(z)
 }
