@@ -1,20 +1,20 @@
 ## File Name: xxirt_createItemList.R
-## File Version: 0.13
+## File Version: 0.141
 
-#########################################################
-# create item list
+
+#--- create item list
 xxirt_createItemList <- function( customItems, itemtype,items, partable )
 {
     #*** list with customized items
     I <- length(items)
-    item_list <- as.list( 1:I )
+    item_list <- as.list( 1L:I )
     names(item_list) <- items
     CI <- length(customItems)
-    for (ii in 1:I){
+    for (ii in 1L:I){
         itemtype_ii <- itemtype[ii]
         item_list[[ii]] <- NA
         partable_ii <- partable[ partable$itemnr==ii, ]
-        for (vv in 1:CI){
+        for (vv in 1L:CI){
             if ( paste(customItems[[vv]]$name)==itemtype_ii ){
                 item_list[[ii]] <- customItems[[vv]]
             }  # end if
@@ -27,4 +27,3 @@ xxirt_createItemList <- function( customItems, itemtype,items, partable )
     }  # end ii
     return(item_list)
 }
-###############################################################
