@@ -1,5 +1,5 @@
 ## File Name: xxirt_createParTable.R
-## File Version: 0.258
+## File Version: 0.271
 
 #*** create parameter table
 xxirt_createParTable <- function( dat, itemtype, customItems=NULL )
@@ -12,10 +12,11 @@ xxirt_createParTable <- function( dat, itemtype, customItems=NULL )
     }
     dfr <- NULL
     CI <- length(customItems)
-    for (ii in 1:I){
+    pc <- 0
+    for (ii in 1L:I){
         type_ii <- itemtype[ii]
         item_ii <- NULL
-        for ( vv in 1:CI){
+        for ( vv in 1L:CI){
             ci_ii <- customItems[[vv]]
             if ( ci_ii$name==type_ii ){
                 item_ii <- ci_ii
@@ -25,7 +26,7 @@ xxirt_createParTable <- function( dat, itemtype, customItems=NULL )
             stop( paste0( 'Item type ', type_ii, ' not found!') )
         }
         NP <- length( item_ii$par )
-        dfr1 <- data.frame( 'item'=rep( items[ii], NP ) )
+        dfr1 <- data.frame( item=rep( items[ii], NP ) )
         dfr1$itemnr <- ii
         dfr1$ncat <- ncat1[ii]
         dfr1$class <- class(item_ii)
@@ -45,16 +46,22 @@ xxirt_createParTable <- function( dat, itemtype, customItems=NULL )
             dfr1[ ind_ii, 'prior_par1' ] <- item_ii$prior_par1
             dfr1[ ind_ii, 'prior_par2' ] <- item_ii$prior_par2
         }
+        if (item_ii$person_covariates){
+            dfr1[,'person_covariates'] <- TRUE
+            pc <- pc + 1
+        }
+
         dfr <- rbind( dfr, dfr1 )
-    }
+    }  # end ii
     #**** create parameter indices
     NP <- nrow(dfr)
-    dfr$rowindex <- 1:NP
+    dfr$rowindex <- 1L:NP
     # parameter index
     dfr$parindex <- cumsum( dfr$est )
     #*** parameter label
     dfr$parlabel <- paste0( dfr$item, '_', dfr$parname )
     attr(dfr, 'ncat' ) <- ncat1
     attr(dfr, 'items' ) <- items
+    attr(dfr, 'person_covariates') <- (pc>0)
     return(dfr)
 }
